@@ -35,6 +35,7 @@
 
 #include <osmocom/sigtran/xua_msg.h>
 #include <osmocom/sigtran/sccp_sap.h>
+#include <osmocom/sigtran/osmo_ss7.h>
 
 #include <osmocom/smlc/debug.h>
 #include <osmocom/smlc/smlc_data.h>
@@ -170,6 +171,7 @@ static struct vty_app_info vty_info = {
 	"This is free software: you are free to change and redistribute it.\r\n"
 	"There is NO WARRANTY, to the extent permitted by law.\r\n",
 	.version	= PACKAGE_VERSION,
+	.go_parent_cb	= osmo_ss7_vty_go_parent,
 };
 
 static void signal_handler(int signal)
@@ -262,7 +264,7 @@ int main(int argc, char **argv)
 	}
 
 	/* Start telnet interface after reading config for vty_get_bind_addr() */
-	rc = telnet_init_dynif(tall_smlc_ctx, g_smlc, vty_get_bind_addr(), OSMO_VTY_PORT_SMLC);
+	rc = telnet_init_default(tall_smlc_ctx, g_smlc, OSMO_VTY_PORT_SMLC);
 	if (rc < 0)
 		exit(1);
 
